@@ -480,11 +480,13 @@ sub _find_prereqs {
         
         while( $found =~ m/(?:\s)([\w\:]+)=>(?:q\[(.*?)\],?|undef)/g ) {
             if( defined $p{$1} ) {
-                msg(loc("Warning: PREREQ_PM mentions '%1' more than once. " .
-                        "Last mention wins.", $1 ), $verbose );
+                my $ver = $cb->_version_to_number(version => $2);
+                $p{$1} = $ver
+                  if $cb->_vcmp( $ver, $p{$1} ) > 0;
+            }
+            else {
+                $p{$1} = $cb->_version_to_number(version => $2);                  
             }
-            
-            $p{$1} = $cb->_version_to_number(version => $2);                  
         }
         last;
     }
@@ -680,7 +682,7 @@ sub create {
                 if ( NO_TESTS_DEFINED->( $captured ) ) {
                     msg( NO_TESTS_DEFINED->( $captured ), 0 )
                 } else {
-                    msg( loc( "MAKE TEST passed: %2", $captured ), $verbose );
+                    msg( loc( "MAKE TEST passed: %1", $captured ), $verbose );
                 }
             
                 $dist->status->test(1);
